# Code of Conduct

> Remember the golden rule? Treat others as you'd like to be treated

## Standards

- Create a welcoming and safe community for `everyone`
- Demonstrate empathy towards others, realize that everyone has a different `level of experience`
- Be respectful of others opinions, viewpoints, and experiences
- Give and receive respectful constructive feedback
- Accept responsibility and apologize when necessary
- Focus on what is best for the overall community

## Failure to Follow Standards

If there is a failure to follow the standards laid out above, the user will first be warned. If the offending behavior continues, the user may be blocked entirely.
